==> cvr-1.2.0.tgz: package/test/test.js <==
"use strict";

var assert = require( "assert" );
var cvr = require( "../source" );
var fs = require( "fs" );
var path = require( "path" );

var accessToken = process.env.GITHUB_TOKEN || require( "./local.json" ).GITHUB_TOKEN;
var gitHubUser = process.env.GITHUB_USER || require( "./local.json" ).GITHUB_USER;
var gitHubRepoOwner = process.env.GITHUB_REPO_OWNER || require( "./local.json" ).GITHUB_REPO_OWNER;
var gitHubRepo = process.env.GITHUB_REPO || require( "./local.json" ).GITHUB_REPO;
var commitHash = process.env.COMMIT_HASH || require( "./local.json" ).COMMIT_HASH;
var webhookUrl = process.env.WEBHOOK_URL || require( "./local.json" ).WEBHOOK_URL;


var getTestReporter = function ( sourceFile, format, coveredFile, linePercent )
{
    return function ( done )
    {
        cvr.getGitHubFile( accessToken, gitHubUser, gitHubRepo, null, coveredFile, function ( err, blob )
        {
            assert.equal( !!err, false );
            assert.equal( !!String( blob ), true );

            var text = String( blob );

            fs.readFile( sourceFile, { encoding: "utf8" }, function ( err, content )
            {
                cvr.getCoverage( content, format, function ( err, cov )
                {
                    assert.equal( Math.floor( cvr.getLineCoveragePercent( cov ) ), linePercent );

                    var coverage = cvr.getFileCoverage( cov, coveredFile );
                    cvr.formatCoverage( coverage, text, coveredFile, function ( err, result )
                    {
                        fs.mkdir( path.join( "tmp" ), function ()
                        {
                            fs.writeFile( path.join( "tmp", "coverage-" + format + ".html" ), result, done );
                        } );
                    } );
                } );
            } );
        } );
    };
};


describe( "git", function ()
{
    it( "should get a list of repos from GitHub", function ( done )
    {
        this.timeout( 20000 );
        cvr.getGitHubRepos( accessToken, function ( err, repos )
        {
            assert( !err );
            assert( repos.length > 0 );
            done();
        } );
    } );

    it( "should get a file from github", function ( done )
    {
        cvr.getGitHubFile( accessToken, gitHubRepoOwner, gitHubRepo, commitHash, "README.md", function ( err, res )
        {
            assert( !err );
            assert( !!res );
            done();
        } );
    } );

    it( "should create a coverage report for a LCOV file",
        getTestReporter( "./test/assets/lcov.info", "lcov", "source/scripts/project/app.js", 42 ) );

    it( "should create a coverage report for a Cobertura file",
        getTestReporter( "./test/assets/cobertura.xml", "cobertura", "source/scripts/project/app.js", 94 ) );

    it( "should create a coverage report for a jacoco file",
        getTestReporter( "./test/assets/jacoco.xml", "jacoco", "source/scripts/project/app.js", 23 ) );

    it( "should create a coverage report for a Go Cover file",
        getTestReporter( "./test/assets/gocover.out", "gocover", "source/scripts/project/app.js", 46 ) );

    it( "should prepend paths", function ()
    {
        assert.equal(
            cvr.prependPath(
                '<class name="app.js" filename="source/scripts/project/app.js" line-rate="0.9459000000000001">',
                "project/", "cobertura" ),
                '<class name="app.js" filename="project/source/scripts/project/app.js" line-rate="0.9459000000000001">' );

        assert.equal(
            cvr.prependPath(
                '<package name="source/scripts/project"><class name="source/scripts/project/app">',
                "project/", "jacoco" ),
                '<package name="project/source/scripts/project"><class name="project/source/scripts/project/app">' );

        assert.equal(
            cvr.prependPath(
                "mode: count\nsource/scripts/project/app.js:44.31,47.2 2 0\nsource/scripts/project/app.js:49.71,54.16 4 7",
                "project/", "gocover" ),
                "mode: count\nproject/source/scripts/project/app.js:44.31,47.2 2 0\nproject/source/scripts/project/app.js:49.71,54.16 4 7" );

        assert.equal(
            cvr.prependPath(
                "TN:\nSF:source/scripts/project/app.js\nFN:5,(anonymous_1)",
                "project/", "lcov" ),
                "TN:\nSF:project/source/scripts/project/app.js\nFN:5,(anonymous_1)" );
    } );

    it( "should remove paths", function ()
    {
        assert.equal(
            cvr.removePath(
                "TN:\nSF:source/scripts/project/app.js\nFN:5,(anonymous_1)",
                "source/scripts/", "lcov" ),
                "TN:\nSF:project/app.js\nFN:5,(anonymous_1)" );
    } );

    it( "should create a webhook", function ( done )
    {
        cvr.createGitHubHook( accessToken, gitHubUser, gitHubRepo, webhookUrl, function ( err, res )
        {
            assert.equal( err, null );
            assert.equal( res.config.url, webhookUrl );
            done();
        } );
    } );

    it( "should delete a webhook", function ( done )
    {
        cvr.deleteGitHubHook( accessToken, gitHubUser, gitHubRepo, webhookUrl, function ( err, res )
        {
            assert.equal( err, null );
            assert.equal( !!res, true );
            done();
        } );
    } );

    it( "should create a status", function ( done )
    {
        var statusMessage = {
            user: gitHubUser,
            repo: gitHubRepo,
            sha: commitHash,
            state: "pending",
            context: "cvr",
            description: "code coverage pending",
            target_url: "http://vokal.io"
        };

        cvr.createGitHubStatus( accessToken, statusMessage, function ( err, res )
        {
            assert.equal( err, null );
            assert.equal( res.state, "pending" );

            statusMessage.state = "success";
            statusMessage.description = "code coverage meets minimum";

            cvr.createGitHubStatus( accessToken, statusMessage, function ( err, res )
            {
                assert.equal( err, null );
                assert.equal( res.state, "success" );
                done();
            } );
        } );
    } );
} );

describe( "Shields", function ()
{
    it( "should get a shield", function ( done )
    {
        cvr.getShield( 80, 80, function ( err, res )
        {
            assert.equal( err, null );
            done();
        } );
    } );
} );

describe( "Utility", function ()
{
    it( "should sort coverage by file path", function ( done )
    {
        var coverageArray = [
            { file: "app/sub/test.html" },
            { file: "app/sub/index.html" },
            { file: "app/index.html" } ];

        var result = cvr.sortCoverage( coverageArray );

        assert.equal( coverageArray[ 0 ].file, "app/index.html" );
        assert.equal( coverageArray[ 1 ].file, "app/sub/index.html" );
        assert.equal( coverageArray[ 2 ].file, "app/sub/test.html" );
        done();
    } );

    it( "should calculate correct coverage percent", function ( done )
    {
        var coverageArray = [];

        assert.equal( cvr.getLineCoveragePercent( coverageArray ), 100 );

        coverageArray = [ { lines: { found: 0, hit: 0 } } ];
        assert.equal( cvr.getLineCoveragePercent( coverageArray ), 100 );

        coverageArray = [ { lines: { found: 4, hit: 1 } } ];
        assert.equal( cvr.getLineCoveragePercent( coverageArray ), 25 );

        done();
    } );

    it( "should get a line", function ( done )
    {
        var coverageArray = [];

        assert.deepEqual( cvr.getLine( coverageArray, 1 ), { active: false, hit: null } );

        coverageArray = coverageArray = [ { line: 1, found: 4, hit: 5 } ];
        assert.deepEqual( cvr.getLine( coverageArray, 1 ), { active: true, hit: 5 } );

        done();
    } );
} );

describe( "File type checking", function ()
{
    it( "should return correct file type", function ( done )
    {
        var fileTypes = {
            "my-style.less": "less",
            "my-styles.css": "css",
            "main.go": "go",
            "Some_other_file.xcode": "clike",
            "urls.py": "python",
            "V34__Create_sp_insert_data.sql": "sql",
            "script.sh": "bash",
            "other-script.bash": "bash",
            "README.md": "markdown",
            "index.js": "javascript"
        };

        for ( var name in fileTypes )
        {
            assert.equal( fileTypes[ name ], cvr.getFileType( name ) );
        };
        done();
    } );
} );

==> cvr-2.0.1.tgz: package/test/test.js <==
"use strict";

var assert = require( "assert" );
var cvr = require( "../source" );
var fs = require( "fs" );
var path = require( "path" );
require( "dotenv" ).load();

var accessToken = process.env.GITHUB_TOKEN;
var webhookUrl = process.env.WEBHOOK_URL;
var gitHubUser = "jrit";
var gitHubRepoOwner = "vokal";
var gitHubRepo = "cvr";
var commitHash = "ef54eb807093e8a1f45f26a624267503ea01932d";
var coveredFile = "source/index.js";


var getTestReporter = function ( sourceFile, format, coveredFile, linePercent )
{
    return function ( done )
    {
        cvr.gitHub.getFile( accessToken, gitHubUser, gitHubRepo, null, coveredFile, function ( err, blob )
        {
            assert.equal( !!err, false, "err should be null: " + err );
            assert.equal( !!String( blob ), true );

            var text = String( blob );

            fs.readFile( sourceFile, { encoding: "utf8" }, function ( err, content )
            {
                cvr.getCoverage( content, format, function ( err, cov )
                {
                    assert.equal( Math.floor( cvr.getLineCoveragePercent( cov ) ), linePercent );

                    var coverage = cvr.getFileCoverage( cov, coveredFile );
                    cvr.formatCoverage( coverage, text, coveredFile, function ( err, result )
                    {
                        fs.mkdir( path.join( "tmp" ), function ()
                        {
                            fs.writeFile( path.join( "tmp", "coverage-" + format + ".html" ), result, done );
                        } );
                    } );
                } );
            } );
        } );
    };
};


describe( "git", function ()
{
    it( "should get a list of repos from GitHub", function ( done )
    {
        this.timeout( 20000 );
        cvr.gitHub.getRepos( accessToken, function ( err, repos )
        {
            assert( !err );
            assert( repos.length > 0 );
            done();
        } );
    } );

    it( "should get a file from github", function ( done )
    {
        cvr.gitHub.getFile( accessToken, gitHubRepoOwner, gitHubRepo, commitHash, "README.md", function ( err, res )
        {
            assert( !err );
            assert( !!res );
            done();
        } );
    } );

    it( "should create a coverage report for a LCOV file",
        getTestReporter( "./test/assets/lcov.info", "lcov", coveredFile, 42 ) );

    it( "should create a coverage report for a Cobertura file",
        getTestReporter( "./test/assets/cobertura.xml", "cobertura", coveredFile, 94 ) );

    it( "should create a coverage report for a jacoco file",
        getTestReporter( "./test/assets/jacoco.xml", "jacoco", coveredFile, 23 ) );

    it( "should create a coverage report for a Go Cover file",
        getTestReporter( "./test/assets/gocover.out", "gocover", coveredFile, 46 ) );

    it( "should prepend paths", function ()
    {
        assert.equal(
            cvr.prependPath(
                '<class name="index.js" filename="source/index.js" line-rate="0.9459000000000001">',
                "project/", "cobertura" ),
                '<class name="index.js" filename="project/source/index.js" line-rate="0.9459000000000001">' );

        assert.equal(
            cvr.prependPath(
                '<package name="source/scripts/project"><class name="source/scripts/project/app">',
                "project/", "jacoco" ),
                '<package name="project/source/scripts/project"><class name="project/source/scripts/project/app">' );

        assert.equal(
            cvr.prependPath(
                "mode: count\nsource/index.js:44.31,47.2 2 0\nsource/index.js:49.71,54.16 4 7",
                "project/", "gocover" ),
                "mode: count\nproject/source/index.js:44.31,47.2 2 0\nproject/source/index.js:49.71,54.16 4 7" );

        assert.equal(
            cvr.prependPath(
                "TN:\nSF:source/index.js\nFN:5,(anonymous_1)",
                "project/", "lcov" ),
                "TN:\nSF:project/source/index.js\nFN:5,(anonymous_1)" );
    } );

    it( "should remove paths", function ()
    {
        assert.equal(
            cvr.removePath(
                "TN:\nSF:source/index.js\nFN:5,(anonymous_1)",
                "source/scripts/", "lcov" ),
                "TN:\nSF:source/index.js\nFN:5,(anonymous_1)" );
    } );

    it( "should create a webhook", function ( done )
    {
        cvr.gitHub.createHook( accessToken, gitHubUser, gitHubRepo, webhookUrl, function ( err, res )
        {
            assert.equal( err, null );
            assert.equal( res.config.url, webhookUrl );
            done();
        } );
    } );

    it( "should delete a webhook", function ( done )
    {
        cvr.gitHub.deleteHook( accessToken, gitHubUser, gitHubRepo, webhookUrl, function ( err, res )
        {
            assert.equal( err, null );
            assert.equal( !!res, true );
            done();
        } );
    } );

    it( "should create a status", function ( done )
    {
        var statusMessage = {
            user: gitHubUser,
            repo: gitHubRepo,
            sha: commitHash,
            state: "pending",
            context: "cvr",
            description: "code coverage pending",
            target_url: "http://vokal.io"
        };

        cvr.gitHub.createStatus( accessToken, statusMessage, function ( err, res )
        {
            assert.equal( err, null );
            assert.equal( res.state, "pending" );

            statusMessage.state = "success";
            statusMessage.description = "code coverage meets minimum";

            cvr.gitHub.createStatus( accessToken, statusMessage, function ( err, res )
            {
                assert.equal( err, null );
                assert.equal( res.state, "success" );
                done();
            } );
        } );
    } );
} );

describe( "Shields", function ()
{
    it( "should get a shield", function ( done )
    {
        cvr.getShield( 80, 80, function ( err, res )
        {
            assert.equal( err, null );
            done();
        } );
    } );
} );

describe( "Utility", function ()
{
    it( "should sort coverage by file path", function ( done )
    {
        var coverageArray = [
            { file: "app/sub/test.html" },
            { file: "app/sub/index.html" },
            { file: "app/index.html" } ];

        var result = cvr.sortCoverage( coverageArray );

        assert.equal( coverageArray[ 0 ].file, "app/index.html" );
        assert.equal( coverageArray[ 1 ].file, "app/sub/index.html" );
        assert.equal( coverageArray[ 2 ].file, "app/sub/test.html" );
        done();
    } );

    it( "should calculate correct coverage percent", function ( done )
    {
        var coverageArray = [];

        assert.equal( cvr.getLineCoveragePercent( coverageArray ), 100 );

        coverageArray = [ { lines: { found: 0, hit: 0 } } ];
        assert.equal( cvr.getLineCoveragePercent( coverageArray ), 100 );

        coverageArray = [ { lines: { found: 4, hit: 1 } } ];
        assert.equal( cvr.getLineCoveragePercent( coverageArray ), 25 );

        done();
    } );

    it( "should get a line", function ( done )
    {
        var coverageArray = [];

        assert.deepEqual( cvr.getLine( coverageArray, 1 ), { active: false, hit: null } );

        coverageArray = coverageArray = [ { line: 1, found: 4, hit: 5 } ];
        assert.deepEqual( cvr.getLine( coverageArray, 1 ), { active: true, hit: 5 } );

        done();
    } );
} );

describe( "File type checking", function ()
{
    it( "should return correct file type", function ( done )
    {
        var fileTypes = {
            "my-style.less": "less",
            "my-styles.css": "css",
            "main.go": "go",
            "Some_other_file.xcode": "clike",
            "urls.py": "python",
            "V34__Create_sp_insert_data.sql": "sql",
            "script.sh": "bash",
            "other-script.bash": "bash",
            "README.md": "markdown",
            "index.js": "javascript"
        };

        for ( var name in fileTypes )
        {
            assert.equal( fileTypes[ name ], cvr.getFileType( name ) );
        };
        done();
    } );
} );
